#include "material.h"

Material::Material()
{
  init();
  
  setName ("");
}

Material::Material (char* mtlName)
{
  init();
  
  setName (mtlName);
}

Material* Material::addMaterial(char* mtlName)
{
  Material* newMat = new Material(mtlName);
  Material* tmpMat = this;
  while (tmpMat->nextMat != NULL)
    {
      tmpMat = tmpMat->nextMat;
    }
      tmpMat->nextMat = newMat;
      return newMat;
  
}

void Material::init(void)
{
  nextMat = NULL;

  setIllum(1);
  setDiffuse(0,0,0);
  setAmbient(0,0,0);
  setSpecular(0,0,0);
  setTransparency(0.0);
}


void Material::setName (char* mtlName)
{
  strcpy(name, mtlName);
  //  printf ("adding new Material: %s, %p\n", this->getName(), this);

}
char* Material::getName (void)
{
  return name;
}


void Material::setIllum (int illum)
{
  illumModel = illum;
  //  printf ("setting illumModel to: %i\n", illumModel);
}
void Material::setIllum (char* illum)
{
  setIllum (atoi(illum));
}

void Material::setDiffuse (float r, float g, float b)
{
  diffuse[0] = r;
  diffuse[1] = g;
  diffuse[2] = b;  
  diffuse[3] = 1.0;

  //  printf ("setting Diffuse Color to r=%f g=%f b=%f\n", r, g, b);
}
void Material::setDiffuse (char* rgb)
{
  char r[20],g[20],b[20];
  sscanf (rgb, "%s %s %s", r, g, b);
  setDiffuse (atof(r), atof(g), atof(b));
}

void Material::setAmbient (float r, float g, float b)
{
  ambient[0] = r;
  ambient[1] = g;
  ambient[2] = b;
  ambient[3] = 1.0;
  //  printf ("setting Ambient Color to r=%f g=%f b=%f\n", r, g, b);
}
void Material::setAmbient (char* rgb)
{
  char r[20],g[20],b[20];
  sscanf (rgb, "%s %s %s", r, g, b);
  setAmbient (atof(r), atof(g), atof(b));
}

void Material::setSpecular (float r, float g, float b)
{
  specular[0] = r;
  specular[1] = g;
  specular[2] = b;
  specular[3] = 1.0;
  //printf ("setting Specular Color to r=%f g=%f b=%f\n", r, g, b);
}
void Material::setSpecular (char* rgb)
{
  char r[20],g[20],b[20];
  sscanf (rgb, "%s %s %s", r, g, b);
  setSpecular (atof(r), atof(g), atof(b));
}


void Material::setTransparency (float trans)
{
  transparency = trans;
}
void Material::setTransparency (char* trans)
{
  char tr[20];
  sscanf (trans, "%s", tr);
  setTransparency (atof(tr));
}


Material* Material::search (char* mtlName)
{
  Material* searcher = this;
  while (searcher != NULL)
    {
      if (!strcmp (searcher->getName(), mtlName))
	return searcher;
      searcher = searcher->nextMat;
    }
  return NULL;
}

bool Material::select (void)
{
  // setting diffuse color
  //  glColor3f (diffuse[0], diffuse[1], diffuse[2]);
  glMaterialfv(GL_FRONT, GL_DIFFUSE, diffuse);

  // setting ambient color
  glMaterialfv(GL_FRONT, GL_AMBIENT, ambient);

  // setting up Sprecular
  glMaterialfv(GL_FRONT, GL_SPECULAR, specular);
  
  // setting illumination Model 
  if (illumModel == 1)
    glShadeModel(GL_FLAT);
  else if (illumModel >= 2)
    glShadeModel(GL_SMOOTH);
}
